==> scrapysplashwrapper-1.1.1.tar.gz: scrapysplashwrapper-1.1.1/scrapysplashwrapper/middleware.py <==
# -*- coding: utf-8 -*-
# This file is part of Viper - https://github.com/viper-framework/viper
# See the file 'LICENSE' for copying permission.

import logging

from scrapy.spidermiddlewares.depth import DepthMiddleware  # type: ignore
from scrapy_splash import SplashRequest  # type: ignore


class ScrapySplashWrapperDepthMiddleware(DepthMiddleware):

    def process_spider_output(self, response, result, spider):
        logger = logging.getLogger(__name__)

        def _filter(request) -> bool:
            if isinstance(request, SplashRequest):
                depth = response.meta['depth'] + 1
                request.meta['depth'] = depth
                if self.prio:
                    request.priority -= depth * self.prio
                if self.maxdepth and depth >= self.maxdepth:
                    logger.debug(
                        "Ignoring link (depth > %(maxdepth)d): %(requrl)s ",
                        {'maxdepth': self.maxdepth, 'requrl': request.url},
                        extra={'spider': spider}
                    )
                    return False
                elif self.stats:
                    if self.verbose_stats:
                        self.stats.inc_value('request_depth_count/%s' % depth,
                                             spider=spider)
                    self.stats.max_value('request_depth_max', depth,
                                         spider=spider)
            return True

        # base case (depth=0)
        if self.stats and 'depth' not in response.meta:
            response.meta['depth'] = 0
            if self.verbose_stats:
                self.stats.inc_value('request_depth_count/0', spider=spider)

        return (r for r in result or () if _filter(r))

==> scrapysplashwrapper-1.8.1.tar.gz: scrapysplashwrapper-1.8.1/scrapysplashwrapper/middleware.py <==
# -*- coding: utf-8 -*-
# This file is part of Viper - https://github.com/viper-framework/viper
# See the file 'LICENSE' for copying permission.

import logging

from scrapy.spidermiddlewares.depth import DepthMiddleware  # type: ignore
from scrapy_splash import SplashRequest  # type: ignore


class ScrapySplashWrapperDepthMiddleware(DepthMiddleware):

    def process_spider_output(self, response, result, spider):  # type: ignore
        logger = logging.getLogger(__name__)

        def _filter(request: SplashRequest) -> bool:
            if isinstance(request, SplashRequest):
                depth = response.meta['depth'] + 1
                request.meta['depth'] = depth
                if self.prio:
                    request.priority -= depth * self.prio
                if self.maxdepth and depth >= self.maxdepth:
                    logger.debug(
                        "Ignoring link (depth > %(maxdepth)d): %(requrl)s ",
                        {'maxdepth': self.maxdepth, 'requrl': request.url},
                        extra={'spider': spider}
                    )
                    return False
                elif self.stats:
                    if self.verbose_stats:
                        self.stats.inc_value('request_depth_count/%s' % depth,
                                             spider=spider)
                    self.stats.max_value('request_depth_max', depth,
                                         spider=spider)
            return True

        # base case (depth=0)
        if self.stats and 'depth' not in response.meta:
            response.meta['depth'] = 0
            if self.verbose_stats:
                self.stats.inc_value('request_depth_count/0', spider=spider)

        return (r for r in result or () if _filter(r))
